template = """\
{
  "docElements": [
    {
      "elementType": "text",
      "id": 3,
      "containerId": "0_header",
      "x": 0,
      "y": 0,
      "width": 822,
      "height": 40,
      "content": "Claim Remuneration",
      "eval": false,
      "styleId": "",
      "bold": true,
      "italic": false,
      "underline": false,
      "strikethrough": false,
      "horizontalAlignment": "center",
      "verticalAlignment": "middle",
      "textColor": "#741b47",
      "backgroundColor": "",
      "font": "helvetica",
      "fontSize": "24",
      "lineSpacing": 1,
      "borderColor": "#000000",
      "borderWidth": 1,
      "borderAll": false,
      "borderLeft": false,
      "borderTop": false,
      "borderRight": false,
      "borderBottom": false,
      "paddingLeft": 2,
      "paddingTop": 2,
      "paddingRight": 2,
      "paddingBottom": 2,
      "printIf": "",
      "removeEmptyElement": false,
      "alwaysPrintOnSamePage": true,
      "pattern": "",
      "link": "",
      "cs_condition": "",
      "cs_styleId": "",
      "cs_bold": false,
      "cs_italic": false,
      "cs_underline": false,
      "cs_strikethrough": false,
      "cs_horizontalAlignment": "left",
      "cs_verticalAlignment": "top",
      "cs_textColor": "#000000",
      "cs_backgroundColor": "",
      "cs_font": "helvetica",
      "cs_fontSize": 12,
      "cs_lineSpacing": 1,
      "cs_borderColor": "#000000",
      "cs_borderWidth": "1",
      "cs_borderAll": false,
      "cs_borderLeft": false,
      "cs_borderTop": false,
      "cs_borderRight": false,
      "cs_borderBottom": false,
      "cs_paddingLeft": 2,
      "cs_paddingTop": 2,
      "cs_paddingRight": 2,
      "cs_paddingBottom": 2,
      "spreadsheet_hide": false,
      "spreadsheet_column": "",
      "spreadsheet_colspan": "",
      "spreadsheet_addEmptyRow": false
    },
    {
      "elementType": "text",
      "id": 324,
      "containerId": "0_header",
      "x": 0,
      "y": 60,
      "width": 822,
      "height": 20,
      "content": "('| Date'+${DateF}+${DateT} + ' ' if len(${DateFrom}+${DateTo}) else '') + ('| Region: '+${RegionName} if len(${RegionName}) else '') + ('| District: '+${DistrictName} if len(${DistrictName}) else '') + ('| Level: '+${HFLevel_str} if len(${HFLevel_str}) else '') + ('| Health Facility: '+${HFName} if len(${HFName}) else '') + ('| Product: '+${ProductCode} if len(${ProductCode}) else '') + ('| Run date: '+${RunDate} if len(${RunDate}) else '')",
      "eval": true,
      "styleId": "",
      "bold": false,
      "italic": false,
      "underline": false,
      "strikethrough": false,
      "horizontalAlignment": "left",
      "verticalAlignment": "top",
      "textColor": "#000000",
      "backgroundColor": "",
      "font": "helvetica",
      "fontSize": 12,
      "lineSpacing": 1,
      "borderColor": "#000000",
      "borderWidth": 1,
      "borderAll": false,
      "borderLeft": false,
      "borderTop": false,
      "borderRight": false,
      "borderBottom": true,
      "paddingLeft": 2,
      "paddingTop": 2,
      "paddingRight": 2,
      "paddingBottom": 2,
      "printIf": "",
      "removeEmptyElement": false,
      "alwaysPrintOnSamePage": true,
      "pattern": "",
      "link": "",
      "cs_condition": "",
      "cs_styleId": "",
      "cs_bold": false,
      "cs_italic": false,
      "cs_underline": false,
      "cs_strikethrough": false,
      "cs_horizontalAlignment": "left",
      "cs_verticalAlignment": "top",
      "cs_textColor": "#000000",
      "cs_backgroundColor": "",
      "cs_font": "helvetica",
      "cs_fontSize": 12,
      "cs_lineSpacing": 1,
      "cs_borderColor": "#000000",
      "cs_borderWidth": "1",
      "cs_borderAll": false,
      "cs_borderLeft": false,
      "cs_borderTop": false,
      "cs_borderRight": false,
      "cs_borderBottom": false,
      "cs_paddingLeft": 2,
      "cs_paddingTop": 2,
      "cs_paddingRight": 2,
      "cs_paddingBottom": 2,
      "spreadsheet_hide": false,
      "spreadsheet_column": "",
      "spreadsheet_colspan": "",
      "spreadsheet_addEmptyRow": false
    },
    {
      "elementType": "table",
      "id": 50,
      "containerId": "0_content",
      "x": 0,
      "y": 0,
      "dataSource": "${data}",
      "columns": 12,
      "header": true,
      "contentRows": "4",
      "footer": true,
      "border": "none",
      "borderColor": "#cccccc",
      "borderWidth": "1",
      "printIf": "",
      "removeEmptyElement": false,
      "spreadsheet_hide": false,
      "spreadsheet_column": "",
      "spreadsheet_addEmptyRow": false,
      "headerData": {
        "elementType": "none",
        "id": 51,
        "height": 40,
        "backgroundColor": "#ffffff",
        "repeatHeader": false,
        "columnData": [
          {
            "elementType": "table_text",
            "id": 52,
            "width": 60,
            "height": 40,
            "content": "Claim",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 53,
            "width": 45,
            "height": 40,
            "content": "Date",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 60,
            "width": 97,
            "height": 40,
            "content": "Claim Admin",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 62,
            "width": 45,
            "height": 40,
            "content": "Date From",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 63,
            "width": 45,
            "height": 40,
            "content": "Date To",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 64,
            "width": 50,
            "height": 40,
            "content": "CHFID",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 65,
            "width": 120,
            "height": 40,
            "content": "Insuree",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 96,
            "width": 140,
            "height": 40,
            "content": "Product",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 99,
            "width": 55,
            "height": 40,
            "content": "Claimed",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 102,
            "width": 55,
            "height": 40,
            "content": "Approved",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 105,
            "width": 55,
            "height": 40,
            "content": "Adjusted",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 108,
            "width": 55,
            "height": 40,
            "content": "Paid",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "center",
            "verticalAlignment": "middle",
            "textColor": "#444444",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "printIf": "",
            "borderWidth": 1
          }
        ]
      },
      "contentDataRows": [
        {
          "elementType": "none",
          "id": 54,
          "height": 22,
          "backgroundColor": "#cccccc",
          "alternateBackgroundColor": "",
          "groupExpression": "${RegionName}",
          "printIf": "",
          "alwaysPrintOnSamePage": true,
          "columnData": [
            {
              "elementType": "table_text",
              "id": 55,
              "width": 60,
              "height": 22,
              "content": "${RegionName}",
              "eval": false,
              "colspan": "8",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "16",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 56,
              "width": 45,
              "height": 22,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 67,
              "width": 97,
              "height": 22,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 69,
              "width": 45,
              "height": 22,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 70,
              "width": 45,
              "height": 22,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 71,
              "width": 50,
              "height": 22,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 72,
              "width": 120,
              "height": 22,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 97,
              "width": 140,
              "height": 22,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 100,
              "width": 55,
              "height": 22,
              "content": "${SUMR_PriceAsked}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "10",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 103,
              "width": 55,
              "height": 22,
              "content": "${SUMR_PriceApproved}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "10",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 106,
              "width": 55,
              "height": 22,
              "content": "${SUMR_PriceAdjusted}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "10",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 109,
              "width": 55,
              "height": 22,
              "content": "${SUMR_RemuneratedAmount}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": true,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "10",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            }
          ]
        },
        {
          "elementType": "none",
          "id": 224,
          "height": 18,
          "backgroundColor": "#dddddd",
          "alternateBackgroundColor": "",
          "groupExpression": "${RegionName}+'-'+${DistrictName}",
          "printIf": "",
          "alwaysPrintOnSamePage": true,
          "columnData": [
            {
              "elementType": "table_text",
              "id": 225,
              "width": 60,
              "height": 18,
              "content": "${DistrictName}",
              "eval": false,
              "colspan": "8",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "14",
              "lineSpacing": 1,
              "paddingLeft": 12,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 226,
              "width": 45,
              "height": 18,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 227,
              "width": 97,
              "height": 18,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 228,
              "width": 45,
              "height": 18,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 229,
              "width": 45,
              "height": 18,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 230,
              "width": 50,
              "height": 18,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 231,
              "width": 120,
              "height": 18,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 232,
              "width": 140,
              "height": 18,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 233,
              "width": 55,
              "height": 18,
              "content": "${SUMD_PriceAsked}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "9",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 234,
              "width": 55,
              "height": 18,
              "content": "${SUMD_PriceApproved}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "9",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 235,
              "width": 55,
              "height": 18,
              "content": "${SUMD_PriceAdjusted}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "9",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 236,
              "width": 55,
              "height": 18,
              "content": "${SUMD_RemuneratedAmount}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#006273",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "9",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            }
          ]
        },
        {
          "elementType": "none",
          "id": 243,
          "height": 16,
          "backgroundColor": "#eeeeee",
          "alternateBackgroundColor": "",
          "groupExpression": "${RegionName}+'-'+${DistrictName}+'-'+${HFCode}",
          "printIf": "",
          "alwaysPrintOnSamePage": true,
          "columnData": [
            {
              "elementType": "table_text",
              "id": 244,
              "width": 60,
              "height": 20,
              "content": "${HFName}",
              "eval": false,
              "colspan": "8",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#444444",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 24,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 245,
              "width": 45,
              "height": 20,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 246,
              "width": 97,
              "height": 20,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 247,
              "width": 45,
              "height": 20,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 248,
              "width": 45,
              "height": 20,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 249,
              "width": 50,
              "height": 20,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 250,
              "width": 120,
              "height": 20,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 251,
              "width": 140,
              "height": 20,
              "content": "",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": 12,
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 252,
              "width": 55,
              "height": 20,
              "content": "${SUMHF_PriceAsked}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 253,
              "width": 55,
              "height": 20,
              "content": "${SUMHF_PriceApproved}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 254,
              "width": 55,
              "height": 20,
              "content": "${SUMHF_PriceAdjusted}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 255,
              "width": 55,
              "height": 20,
              "content": "${SUMHF_RemuneratedAmount}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "middle",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            }
          ]
        },
        {
          "elementType": "none",
          "id": 262,
          "height": 16,
          "backgroundColor": "",
          "alternateBackgroundColor": "#f3f3f3",
          "groupExpression": "",
          "printIf": "",
          "alwaysPrintOnSamePage": true,
          "columnData": [
            {
              "elementType": "table_text",
              "id": 263,
              "width": 60,
              "height": 20,
              "content": "${ClaimCode}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 264,
              "width": 45,
              "height": 20,
              "content": "${DateClaimed}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 265,
              "width": 97,
              "height": 20,
              "content": "${LastNameAdmin} ${OtherNamesAdmin}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "center",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 266,
              "width": 45,
              "height": 20,
              "content": "${DateFrom}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 267,
              "width": 45,
              "height": 20,
              "content": "${DateTo}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "left",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 268,
              "width": 50,
              "height": 20,
              "content": "${CHFID}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "center",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 269,
              "width": 120,
              "height": 20,
              "content": "${LastName} ${OtherNames}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "center",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 270,
              "width": 140,
              "height": 20,
              "content": "${ProductCode} ${ProductName}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "center",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 271,
              "width": 55,
              "height": 20,
              "content": "${PriceAsked}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 272,
              "width": 55,
              "height": 20,
              "content": "${PriceApproved}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 273,
              "width": 55,
              "height": 20,
              "content": "${PriceAdjusted}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            },
            {
              "elementType": "table_text",
              "id": 274,
              "width": 55,
              "height": 20,
              "content": "${RemuneratedAmount}",
              "eval": false,
              "colspan": "",
              "styleId": "",
              "bold": false,
              "italic": false,
              "underline": false,
              "horizontalAlignment": "right",
              "verticalAlignment": "top",
              "textColor": "#000000",
              "backgroundColor": "",
              "font": "helvetica",
              "fontSize": "8",
              "lineSpacing": 1,
              "paddingLeft": 2,
              "paddingTop": 2,
              "paddingRight": 2,
              "paddingBottom": 2,
              "removeEmptyElement": false,
              "alwaysPrintOnSamePage": true,
              "pattern": "",
              "link": "",
              "cs_condition": "",
              "cs_styleId": "",
              "cs_bold": false,
              "cs_italic": false,
              "cs_underline": false,
              "cs_horizontalAlignment": "left",
              "cs_verticalAlignment": "top",
              "cs_textColor": "#000000",
              "cs_backgroundColor": "",
              "cs_font": "helvetica",
              "cs_fontSize": 12,
              "cs_lineSpacing": 1,
              "cs_paddingLeft": 2,
              "cs_paddingTop": 2,
              "cs_paddingRight": 2,
              "cs_paddingBottom": 2,
              "borderWidth": 1
            }
          ]
        }
      ],
      "footerData": {
        "elementType": "none",
        "id": 57,
        "height": 14,
        "backgroundColor": "",
        "columnData": [
          {
            "elementType": "table_text",
            "id": 58,
            "width": 60,
            "height": 14,
            "content": "",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": false,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "left",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": 12,
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 59,
            "width": 45,
            "height": 14,
            "content": "",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": false,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "left",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": 12,
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 74,
            "width": 97,
            "height": 14,
            "content": "",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": false,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "left",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": 12,
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 76,
            "width": 45,
            "height": 14,
            "content": "",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": false,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "left",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": 12,
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 77,
            "width": 45,
            "height": 14,
            "content": "",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": false,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "left",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": 12,
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 78,
            "width": 50,
            "height": 14,
            "content": "",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": false,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "left",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": 12,
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 79,
            "width": 120,
            "height": 14,
            "content": "",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": false,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "left",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": 12,
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 98,
            "width": 140,
            "height": 14,
            "content": "Overall Total",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "right",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 101,
            "width": 55,
            "height": 14,
            "content": "${ClaimedTotal}",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "right",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 104,
            "width": 55,
            "height": 14,
            "content": "${ApprovedTotal}",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "right",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 107,
            "width": 55,
            "height": 14,
            "content": "${AdjustedTotal}",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "right",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          },
          {
            "elementType": "table_text",
            "id": 110,
            "width": 55,
            "height": 14,
            "content": "${PaidTotal}",
            "eval": false,
            "colspan": "",
            "styleId": "",
            "bold": true,
            "italic": false,
            "underline": false,
            "horizontalAlignment": "right",
            "verticalAlignment": "top",
            "textColor": "#000000",
            "backgroundColor": "",
            "font": "helvetica",
            "fontSize": "10",
            "lineSpacing": 1,
            "paddingLeft": 2,
            "paddingTop": 2,
            "paddingRight": 2,
            "paddingBottom": 2,
            "removeEmptyElement": false,
            "alwaysPrintOnSamePage": true,
            "pattern": "",
            "link": "",
            "cs_condition": "",
            "cs_styleId": "",
            "cs_bold": false,
            "cs_italic": false,
            "cs_underline": false,
            "cs_horizontalAlignment": "left",
            "cs_verticalAlignment": "top",
            "cs_textColor": "#000000",
            "cs_backgroundColor": "",
            "cs_font": "helvetica",
            "cs_fontSize": 12,
            "cs_lineSpacing": 1,
            "cs_paddingLeft": 2,
            "cs_paddingTop": 2,
            "cs_paddingRight": 2,
            "cs_paddingBottom": 2,
            "borderWidth": 1
          }
        ]
      }
    },
    {
      "elementType": "text",
      "id": 7,
      "containerId": "0_footer",
      "x": 567,
      "y": 0,
      "width": 255,
      "height": 30,
      "content": "Page ${page_number} / ${page_count}",
      "eval": false,
      "styleId": "",
      "bold": false,
      "italic": false,
      "underline": false,
      "strikethrough": false,
      "horizontalAlignment": "right",
      "verticalAlignment": "middle",
      "textColor": "#666666",
      "backgroundColor": "",
      "font": "helvetica",
      "fontSize": 12,
      "lineSpacing": 1,
      "borderColor": "#000000",
      "borderWidth": 1,
      "borderAll": false,
      "borderLeft": false,
      "borderTop": false,
      "borderRight": false,
      "borderBottom": false,
      "paddingLeft": 2,
      "paddingTop": 2,
      "paddingRight": 2,
      "paddingBottom": 2,
      "printIf": "",
      "removeEmptyElement": false,
      "alwaysPrintOnSamePage": true,
      "pattern": "",
      "link": "",
      "cs_condition": "",
      "cs_styleId": "",
      "cs_bold": false,
      "cs_italic": false,
      "cs_underline": false,
      "cs_strikethrough": false,
      "cs_horizontalAlignment": "left",
      "cs_verticalAlignment": "top",
      "cs_textColor": "#000000",
      "cs_backgroundColor": "",
      "cs_font": "helvetica",
      "cs_fontSize": 12,
      "cs_lineSpacing": 1,
      "cs_borderColor": "#000000",
      "cs_borderWidth": "1",
      "cs_borderAll": false,
      "cs_borderLeft": false,
      "cs_borderTop": false,
      "cs_borderRight": false,
      "cs_borderBottom": false,
      "cs_paddingLeft": 2,
      "cs_paddingTop": 2,
      "cs_paddingRight": 2,
      "cs_paddingBottom": 2,
      "spreadsheet_hide": false,
      "spreadsheet_column": "",
      "spreadsheet_colspan": "",
      "spreadsheet_addEmptyRow": false
    },
    {
      "elementType": "text",
      "id": 8,
      "containerId": "0_footer",
      "x": 0,
      "y": 0,
      "width": 290,
      "height": 30,
      "content": "Created on ${current_date}",
      "eval": false,
      "styleId": "",
      "bold": false,
      "italic": false,
      "underline": false,
      "strikethrough": false,
      "horizontalAlignment": "left",
      "verticalAlignment": "middle",
      "textColor": "#666666",
      "backgroundColor": "",
      "font": "helvetica",
      "fontSize": 12,
      "lineSpacing": 1,
      "borderColor": "#000000",
      "borderWidth": 1,
      "borderAll": false,
      "borderLeft": false,
      "borderTop": false,
      "borderRight": false,
      "borderBottom": false,
      "paddingLeft": 2,
      "paddingTop": 2,
      "paddingRight": 2,
      "paddingBottom": 2,
      "printIf": "",
      "removeEmptyElement": false,
      "alwaysPrintOnSamePage": true,
      "pattern": "",
      "link": "",
      "cs_condition": "",
      "cs_styleId": "",
      "cs_bold": false,
      "cs_italic": false,
      "cs_underline": false,
      "cs_strikethrough": false,
      "cs_horizontalAlignment": "left",
      "cs_verticalAlignment": "top",
      "cs_textColor": "#000000",
      "cs_backgroundColor": "",
      "cs_font": "helvetica",
      "cs_fontSize": 12,
      "cs_lineSpacing": 1,
      "cs_borderColor": "#000000",
      "cs_borderWidth": "1",
      "cs_borderAll": false,
      "cs_borderLeft": false,
      "cs_borderTop": false,
      "cs_borderRight": false,
      "cs_borderBottom": false,
      "cs_paddingLeft": 2,
      "cs_paddingTop": 2,
      "cs_paddingRight": 2,
      "cs_paddingBottom": 2,
      "spreadsheet_hide": false,
      "spreadsheet_column": "",
      "spreadsheet_colspan": "",
      "spreadsheet_addEmptyRow": false
    }
  ],
  "parameters": [
    {
      "id": 1,
      "name": "page_count",
      "type": "number",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": true,
      "testData": ""
    },
    {
      "id": 2,
      "name": "page_number",
      "type": "number",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": true,
      "testData": ""
    },
    {
      "id": 9,
      "name": "current_date",
      "type": "date",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "d. MMMM yyyy, H:mm",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 38,
      "name": "data",
      "type": "array",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": "",
      "children": [
        {
          "id": 40,
          "name": "row_number",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": true,
          "testData": ""
        },
        {
          "id": 81,
          "name": "ClaimCode",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 82,
          "name": "DateClaimed",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 83,
          "name": "OtherNamesAdmin",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 84,
          "name": "LastNameAdmin",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 41,
          "name": "DateFrom",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 42,
          "name": "DateTo",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 43,
          "name": "CHFID",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 44,
          "name": "OtherNames",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 45,
          "name": "LastName",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 47,
          "name": "HFCode",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 48,
          "name": "HFName",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 49,
          "name": "AccCode",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 86,
          "name": "ProductCode",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 87,
          "name": "ProductName",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 88,
          "name": "PriceAsked",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 89,
          "name": "PriceApproved",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 90,
          "name": "PriceAdjusted",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 91,
          "name": "RemuneratedAmount",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 93,
          "name": "DistrictName",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 95,
          "name": "RegionName",
          "type": "string",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 364,
          "name": "SUMR_PriceAsked",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 365,
          "name": "SUMR_PriceApproved",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 366,
          "name": "SUMR_PriceAdjusted",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 367,
          "name": "SUMR_RemuneratedAmount",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 368,
          "name": "SUMD_PriceAsked",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 369,
          "name": "SUMD_PriceApproved",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 370,
          "name": "SUMD_PriceAdjusted",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 371,
          "name": "SUMD_RemuneratedAmount",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 372,
          "name": "SUMHF_PriceAsked",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 373,
          "name": "SUMHF_PriceApproved",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 374,
          "name": "SUMHF_PriceAdjusted",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        },
        {
          "id": 375,
          "name": "SUMHF_RemuneratedAmount",
          "type": "number",
          "arrayItemType": "string",
          "eval": false,
          "nullable": false,
          "pattern": "#,##0",
          "expression": "",
          "showOnlyNameType": false,
          "testData": ""
        }
      ]
    },
    {
      "id": 39,
      "name": "ClaimedTotal",
      "type": "sum",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "#,##0",
      "expression": "${data.PriceAsked}",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 319,
      "name": "ApprovedTotal",
      "type": "sum",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "#,##0",
      "expression": "${data.PriceApproved}",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 320,
      "name": "AdjustedTotal",
      "type": "sum",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "#,##0",
      "expression": "${data.PriceAdjusted}",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 321,
      "name": "PaidTotal",
      "type": "sum",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "#,##0",
      "expression": "${data.RemuneratedAmount}",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 322,
      "name": "DateFrom",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 323,
      "name": "DateTo",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 377,
      "name": "DateF",
      "type": "string",
      "arrayItemType": "string",
      "eval": true,
      "nullable": true,
      "pattern": "",
      "expression": "' from ' + ${DateFrom} if len(${DateFrom}) else ''",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 378,
      "name": "DateT",
      "type": "string",
      "arrayItemType": "string",
      "eval": true,
      "nullable": false,
      "pattern": "",
      "expression": "' to ' + ${DateTo} if len(${DateTo}) else ''",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 382,
      "name": "RegionCode",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 379,
      "name": "RegionName",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": true,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 388,
      "name": "DistrictCode",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 389,
      "name": "DistrictName",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 383,
      "name": "HFCode",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 380,
      "name": "HFName",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 384,
      "name": "HFLevel",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 381,
      "name": "ProductCode",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 385,
      "name": "ProductName",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 386,
      "name": "RunDate",
      "type": "string",
      "arrayItemType": "string",
      "eval": false,
      "nullable": false,
      "pattern": "",
      "expression": "",
      "showOnlyNameType": false,
      "testData": ""
    },
    {
      "id": 387,
      "name": "HFLevel_str",
      "type": "string",
      "arrayItemType": "string",
      "eval": true,
      "nullable": false,
      "pattern": "",
      "expression": "'Hospital' if ${HFLevel} == 'H' else ('Dispensary' if ${HFLevel} == 'C' else ( 'Health Center' if ${HFLevel} == 'C' else ''))",
      "showOnlyNameType": false,
      "testData": "HFLevel_str"
    }
  ],
  "styles": [
    {
      "id": 33,
      "name": "Table Header",
      "bold": true,
      "italic": false,
      "underline": false,
      "strikethrough": false,
      "horizontalAlignment": "center",
      "verticalAlignment": "middle",
      "textColor": "#000000",
      "backgroundColor": "",
      "font": "helvetica",
      "fontSize": "10",
      "lineSpacing": 1,
      "borderColor": "#000000",
      "borderWidth": "1",
      "borderAll": false,
      "borderLeft": false,
      "borderTop": false,
      "borderRight": false,
      "borderBottom": false,
      "paddingLeft": "2",
      "paddingTop": "2",
      "paddingRight": "2",
      "paddingBottom": "2"
    },
    {
      "id": 34,
      "name": "Table Content",
      "bold": false,
      "italic": false,
      "underline": false,
      "strikethrough": false,
      "horizontalAlignment": "left",
      "verticalAlignment": "middle",
      "textColor": "#000000",
      "backgroundColor": "",
      "font": "helvetica",
      "fontSize": "9",
      "lineSpacing": 1,
      "borderColor": "#000000",
      "borderWidth": "1",
      "borderAll": false,
      "borderLeft": false,
      "borderTop": false,
      "borderRight": false,
      "borderBottom": false,
      "paddingLeft": "2",
      "paddingTop": "2",
      "paddingRight": "2",
      "paddingBottom": "2"
    },
    {
      "id": 35,
      "name": "Table Content Highlight",
      "bold": true,
      "italic": false,
      "underline": false,
      "strikethrough": false,
      "horizontalAlignment": "center",
      "verticalAlignment": "middle",
      "textColor": "#3d85c6",
      "backgroundColor": "",
      "font": "helvetica",
      "fontSize": "9",
      "lineSpacing": 1,
      "borderColor": "#000000",
      "borderWidth": "1",
      "borderAll": false,
      "borderLeft": false,
      "borderTop": false,
      "borderRight": false,
      "borderBottom": false,
      "paddingLeft": "2",
      "paddingTop": "2",
      "paddingRight": "2",
      "paddingBottom": "2"
    }
  ],
  "version": 2,
  "documentProperties": {
    "pageFormat": "A4",
    "pageWidth": "",
    "pageHeight": "",
    "unit": "mm",
    "orientation": "landscape",
    "contentHeight": "",
    "marginLeft": "10",
    "marginTop": "10",
    "marginRight": "10",
    "marginBottom": "10",
    "header": true,
    "headerSize": "80",
    "headerDisplay": "always",
    "footer": true,
    "footerSize": "30",
    "footerDisplay": "always",
    "patternLocale": "en",
    "patternCurrencySymbol": "$"
  }
}
"""